Last Updated: 2024-11-01 15:28:58 UTC

Lines Changed: +6, -0

# Concrete Database Integration
Provides an integration to save concrete objects to disc with a SQLAlchemy ORM built with SQLModel and Pydantic Model.